### Install requisite packages if needed:

install.packages(c("ape", "geiger", "caper", "evomap", "phytools", "gdata", "rms", "diversitree", "strap", "paleotree", "picante", "devtools"), dependencies=TRUE)

#Install evomap from github
library(devtools)
install_github("JeroenSmaers/evomap")

#load packages
library(ape)
library(geiger)
library(caper)
library(evomap)
require(phytools)
require(gdata)
library(rms)
library(diversitree)
library(strap)
library(paleotree)
library(picante)



#Set working directory and upload phylogeny

setwd("## Set your own working directory")  ##Set your working directory by dragging and dropping the supplemental R code folder between the quotation  marks (" ")

tree<-read.tree("time-scaled-theropod-phylogeny_B.tre.phy")


####################################################################
####################################################################
##### Adjust tree attributes:

## Tree format checks:

plot(tree, cex=0.4)

is.rooted(tree)		#yes!

#but make sure root is correct anyway:

tree<-root(tree,"Dilophosaurus_wetherelli")

#Is the tree fully bifurcating?

is.binary.tree(tree)		#FALSE- polytomy for Gorgosaurus

## What are the branch lengths?

tree$edge.length					#Branch lengths are scaled for time in mya


dev.off()

####################################################################
####################################################################
##### Input Agility Data

data<-read.csv("Log10_Theropod_Agility_Data_Table_En_Pointe.csv",row.names=1, header=TRUE)

data

data[,2:3]<-log10(data[,2:3])

head(data)

data<-as.data.frame(data)

#Check respresentation of tree and data species:

name.check(data, tree)		#"OK!"

## Data rownames and phylogeny tip names must agree:
tree<-treedata(tree,data,sort=TRUE,warnings=TRUE)$phy
data<-as.data.frame(treedata(tree,data,sort=TRUE,warnings=TRUE)$data)

#Will delete Daspletosaurus sp. from tree because it's not in the dataset


########################################################################
########################################################################
########Standard data inspection:

#Plot variables together:

plot(data[,1],data[,2], xlab="Mass (log10 Kg)", ylab="Agility Force")
text(data[,1],data[,2],row.names(data), cex=0.4, pos=1)

plot(data[,1],data[,3], xlab="Mass (log10 Kg)", ylab="Agility Moment")
text(data[,1],data[,3],row.names(data), cex=0.4, pos=1)

#Visually inspect data for normality:

##Is mass normally distributed?

qqnorm(data[,1])
text(qqnorm(data[,1]),row.names(data), cex=0.4, pos=1)
qqline(data[,1],distribution=qnorm,probs=c(0.25, 0.75),col="red")


#Is agility force normally distributed?
qqnorm(data[,2])
text(qqnorm(data[,2]),row.names(data), cex=0.4, pos=1)
qqline(data[,2],distribution=qnorm,probs=c(0.25, 0.75),col="red")



#Is agility moment normally distributed?
qqnorm(data[,3])
text(qqnorm(data[,3]),row.names(data), cex=0.4, pos=1)
qqline(data[,3],distribution=qnorm,probs=c(0.25, 0.75),col="red")

##Consider removing Raptorex_kriegsteini


qqplot(data[,1],data[,2])

qqplot(data$Mass,data$Agility_Moment)

dev.off()

##################################################################

#Remove Raptorex if desired:

#tree<- drop.tip(tree, "Raptorex_kriegsteini-Tarbosaurus_bataar", trim.internal=TRUE)

#Drop Raptorex from dataset and re-sort:

#tree<-treedata(tree,data,sort=TRUE,warnings=TRUE)$phy
#data<-as.data.frame(treedata(tree,data,sort=TRUE,warnings=TRUE)$data)


##########################################################################################################################################
### Check phylogenetic signal in each variable:

lambda_Force<-phylosig(tree,data$Agility_Force,method="lambda", test=TRUE, nsim=999)
lambda_Force

lambda_Moment<-phylosig(tree,data$Agility_Moment,method="lambda", test=TRUE, nsim=999)
lambda_Moment

lambda_Mass<-phylosig(tree,data$Mass,method="lambda",test=TRUE, nsim=999)
lambda_Mass

##There is phylogenetic signal in all variables (only mass has sig p value)

##########################################################################################################################################
Y<-"Agility_Force"
X<-"Mass"


##########################################################################################################################################
#pgls
##########################################################################################################################################

#Get Agility Force and Mass variables
      Yvar<-data[,which(colnames(data)==paste(Y)),drop=F]
      Xvar<-data[,which(colnames(data)==paste(X)),drop=F]
      data<-cbind(Xvar,Yvar)
      data
      
 ### Evaluate need for PGLS using residuals from OLS:
 
 #ols

Force_ols<-ols(Yvar[,1]~Xvar[,1], data=data)
Force_ols     

lambda_Resid<-phylosig(tree,Force_ols$residuals, method="lambda", test=TRUE, nsim=999)
lambda_Resid
 
#Significant phylogenetic signal in the residuals = need to phylogenetically correct
 
 #pgls
      #Prep pgls
          data_pgls<-cbind(data,rownames(data))
          tree_pgls<-tree
          colnames(data_pgls)[which(colnames(data_pgls)=="rownames(data)")]<-"Species"
          data.pgls<-comparative.data(tree_pgls,data_pgls,vcv=TRUE,names.col=Species)
      #Run pgls
          model<-pgls(Yvar[,1]~Xvar[,1],data=data.pgls,lambda='ML')
          model

#Get regression statistics:
summary(model)
          
###################################################################################
###################################################################################          
###################################################################################
### Prep for ANCOVA 1: Agility FORCE

## Get tip labels:

n<-length(tree$tip.label)
plot(tree, cex=0.4)
tiplabels()			#Use tip labels to assign group

#Assign Groups:

Theropods<-c(1:6, 18:20)
length(Theropods)
Tyrannosaurs<-c(8,9,11,13,14,16)
length(Tyrannosaurs)
Juveniles<-c(7,10,12,15,17)
length(Juveniles)

#Make sure groups add up to total number of individuals
n == ((length(Theropods)) + (length(Tyrannosaurs)) + (length(Juveniles)))
#TRUE


#Color-code groups:

tip.col<-rep("black",length(tree$tip.label))
tip.col[Theropods]<-"red"; tip.col[Tyrannosaurs]<-"blue"; tip.col[Juveniles]<-"skyblue1"

#Make Names Vector

dino.names<-c("A. atokensis NCSM 14345", "G. carolinii MUCv-CH-1", "A. jimmadseni MOR 693", "A. fragilis USNM 4734", "Y. shangyouensis CV 00215", "S. hepingensis ZDM 0024", "R. kriegsteini / T. bataar LH PV18", "T. bataar PIN 552 1", "T. bataar ZPAL MgD-I/4", "T. bataar ZPAL MgD-I/3", "T. rex FMNH PR 2081", "T. rex BMRP 2002.4.1", "T. rex AMNH 5027", "D. torosus CMN 8506", "G. libratus AMNH 5664", "G. libratus AMNH 5458", "G. libratus TMP 91.36.500", "E. oxoniensis OUM J13558", "C. nasicornis USNM 4735", "D. wetherelli UCMP 37302")


data$Names<-dino.names

head(data)


##Check classification

plot(tree,label.offset=5, cex=0.5)
tiplabels(pch=19,col=tip.col,cex=3)

dev.off()

#Plot data
Y_lab<-"Agility Force en Pointe"
X_lab<-"Estimated Body Mass (log10 kg)"

plot(Yvar[,1]~Xvar[,1], ylab=paste0(Y_lab), xlab=paste0(X_lab), pch=20, col=tip.col, cex=2, cex.lab=1, xlim=c(1.5,4.25))
title(main="PGLS of Theropod Agility Force en Pointe",cex.main=1.5)
abline(model, lwd=2)
#abline(Force_ols,col="blue", lwd=3,lty=2)

legend("topright", legend=c("Theropods","Tyrannosaurs","Putative Juveniles"),text.col=c("red","blue","skyblue1"))

text(model$data$data, data$Names,cex=0.6, pos=3)


#Intervals

#Prep data

tree<-rescale(tree,"lambda",model$param[2])
vcv_tree<-vcv(tree)

#confidence intervals
model_ci<-gls.ci(Yvar[,1],Xvar[,1],vcv_tree)
model_ci$model
lines(model_ci$CI.plot$X,model_ci$CI.plot$Lower2.5,lwd=2,lty=4,col="gray47")
lines(model_ci$CI.plot$X,model_ci$CI.plot$Upper2.5,lwd=2,lty=4,col="gray47")

#prediction intervals
k<-1
model_pi<-gls.pi(Yvar[,1],Xvar[,1],vcv_tree,k)
model_pi$model
lines(model_pi$PI.plot$X,model_pi$PI.plot$Lower2.5,lwd=2,lty=3,col="gray")
lines(model_pi$PI.plot$X,model_pi$PI.plot$Upper2.5,lwd=2,lty=3,col="gray")

dev.off()

##################
##################
## Design Matrices for phylANCOVA

# Classify groups
Juv<-Juveniles
JuvRest<-setdiff(c(1:length(tree$tip.label)),Juv)

Theropods<-Theropods
TheropodsRest<-setdiff(c(1:length(tree$tip.label)),Theropods)

Tyrannosaurs<-setdiff(c(1:length(tree$tip.label)),c(Juv,Theropods))  #Tyrannosaurs
TyrannosaursRest<-setdiff(c(1:length(tree$tip.label)),Tyrannosaurs)

Sigma<-vcv(rescale(tree,"lambda",model$param[[2]]))
n<-length(tree$tip.label)


#### Build Design Matrices

#Difference in Intercept
    #general model
        designMatrix<-cbind(rep(1,n),scale(Xvar))
        designMatrix

###
    #Juv model
                group1<-rep(length(Juv),n)
                group1[Juv]<-c(-length(JuvRest))
              sum(group1)
        designMatrix_Juv<-cbind(rep(1,n),group1,scale(Xvar))
        designMatrix_Juv
        
        
###
    #Among model with Juv constant
                group1<-rep(length(Juv),n)
                group1[Juv]<-c(-length(JuvRest))
              sum(group1)   #column sums to zero to reduce rounding errors; applies to all folTheropodsing design matrices 
                group2<-rep(1,n)
                group2[Theropods]<-c(length(Tyrannosaurs))
                group2[Tyrannosaurs]<-c(-length(Theropods))
                group2[Juv]<-c(0)
              sum(group2)   #column sums to zero to reduce rounding errors; applies to all folTheropodsing design matrices 
        designMatrix_Among_JuvConstant<-cbind(rep(1,n),group1,group2,scale(Xvar))    #independent variable is standardized to reduce rounding errors; applies to all folTheropodsing design matrices 
        designMatrix_Among_JuvConstant


###
    #Among model with Theropods constant
                group1<-rep(length(Juv),n)
                group1[Juv]<-c(-length(JuvRest))
              sum(group1)   #column sums to zero to reduce rounding errors; applies to all folTheropodsing design matrices 
                group2<-rep(1,n)
                group2[Theropods]<-c(0)
                group2[Tyrannosaurs]<-c(length(Juv))
                group2[Juv]<-c(-length(Tyrannosaurs))
              sum(group2)   #column sums to zero to reduce rounding errors; applies to all folTheropodsing design matrices 
        designMatrix_Among_TheropodsConstant<-cbind(rep(1,n),group1,group2,scale(Xvar))    #independent variable is standardized to reduce rounding errors; applies to all folTheropodsing design matrices 
        designMatrix_Among_TheropodsConstant


###
    #Theropods model
                group1<-rep(length(Theropods),n)
                group1[Theropods]<-c(-length(TheropodsRest))
              sum(group1)
        designMatrix_Theropods<-cbind(rep(1,n),group1,scale(Xvar))
        designMatrix_Theropods


###
    #TyrannosaursvTheropods model
                group2<-rep(1,n)
                group2[Theropods]<-c(length(Tyrannosaurs))
                group2[Tyrannosaurs]<-c(-length(Theropods))
                group2[Juv]<-c(0)
              sum(group2)
        designMatrix_TyrannosaursvTheropods<-cbind(rep(1,n),group2,scale(Xvar))
        designMatrix_TyrannosaursvTheropods


###
    #JuvvTyrannosaurs model
                group2<-rep(1,n)
                group2[Theropods]<-c(0)
                group2[Tyrannosaurs]<-c(length(Juv))
                group2[Juv]<-c(-length(Tyrannosaurs))
              sum(group2)
        designMatrix_JuvvTyrannosaurs<-cbind(rep(1,n),group2,scale(Xvar))
        designMatrix_JuvvTyrannosaurs
        
        
#Difference in Intercept (tests are for whatever columns of X are left out. Those left in are being held constant. Columns not in either are being ignored.)

      #Among groups
          ReducedModel<-designMatrix
          FullModel<-designMatrix_Among_JuvConstant
          as.data.frame(cbind(tree$tip.label,ReducedModel))
          as.data.frame(cbind(tree$tip.label,FullModel))
          Among<-as.matrix(gls.ancova(Yvar[,1],Xvar[,1],Sigma,ReducedModel,FullModel))
      #Juv v Tyrannosaurs | Theropods
          ReducedModel<-designMatrix_Theropods
          FullModel<-designMatrix_Among_TheropodsConstant
          as.data.frame(cbind(tree$tip.label,ReducedModel))
          as.data.frame(cbind(tree$tip.label,FullModel))
          JuvvTyrannosaurs<-as.matrix(gls.ancova(Yvar[,1],Xvar[,1],Sigma,ReducedModel,FullModel))
      #Tyrannosaurs v Theropods | Juv
          ReducedModel<-designMatrix_Juv
          FullModel<-designMatrix_Among_JuvConstant
          as.data.frame(cbind(tree$tip.label,ReducedModel))
          as.data.frame(cbind(tree$tip.label,FullModel))
          TyrannosaursvTheropods<-as.matrix(gls.ancova(Yvar[,1],Xvar[,1],Sigma,ReducedModel,FullModel))
          
          
#getResults
    Results_ancova<-rbind(
      cbind(as.numeric(Among[1,4]),as.numeric(Among[1,5])),
      cbind(as.numeric(JuvvTyrannosaurs[1,4]),as.numeric(JuvvTyrannosaurs[1,5])),
      cbind(as.numeric(TyrannosaursvTheropods[1,4]),as.numeric(TyrannosaursvTheropods[1,5]))
      )
    rownames(Results_ancova)<-c(
      "Among","JuvvTyrannosaurs","TyrannosaursvTheropods")
    colnames(Results_ancova)<-c("F","P")
    Results_ancova    

#                             F      P
#Among                  11.9197 0.0007
#JuvvTyrannosaurs        0.2970 0.5933
#TyrannosaursvTheropods 21.4412 0.0003    


###################################################################################
###################################################################################          
###################################################################################
### Prep for ANCOVA 2: Agility MOMENT

######## Read back in data:

tree<-read.tree("time-scaled-theropod-phylogeny_B.tre.phy")


####################################################################
####################################################################
##### Adjust tree attributes:

## Tree format checks:

plot(tree, cex=0.4)

is.rooted(tree)		#yes!

#but make sure root is correct anyway:

tree<-root(tree,"Dilophosaurus_wetherelli")

#Is the tree fully bifurcating?

is.binary.tree(tree)		#FALSE- polytomy for Gorgosaurus

## What are the branch lengths?

tree$edge.length					#Branch lengths are scaled for time in mya


dev.off()

####################################################################
####################################################################
##### Input Agility Data

data<-read.csv("Log10_Theropod_Agility_Data_Table_En_Pointe.csv",row.names=1, header=TRUE)

data

data[,2:3]<-log10(data[,2:3])

head(data)

data<-as.data.frame(data)

#Check respresentation of tree and data species:

name.check(data, tree)		#"OK!"

## Data rownames and phylogeny tip names must agree:
tree<-treedata(tree,data,sort=TRUE,warnings=TRUE)$phy
data<-as.data.frame(treedata(tree,data,sort=TRUE,warnings=TRUE)$data)

#Will delete Daspletosaurus sp. from tree and dataset


##########################################################################################################################################
Y<-"Agility_Moment"
X<-"Mass"

##########################################################################################################################################
#pgls
##########################################################################################################################################

#Get variables
      Yvar<-data[,which(colnames(data)==paste(Y)),drop=F]
      Xvar<-data[,which(colnames(data)==paste(X)),drop=F]
      data<-cbind(Xvar,Yvar)
      data
      
 #pgls
      #Prep pgls
          data_pgls<-cbind(data,rownames(data))
          tree_pgls<-tree
          colnames(data_pgls)[which(colnames(data_pgls)=="rownames(data)")]<-"Species"
          data.pgls<-comparative.data(tree_pgls,data_pgls,vcv=TRUE,names.col=Species)
      #Run pgls
          model<-pgls(Yvar[,1]~Xvar[,1],data=data.pgls,lambda='ML')
          model
summary(model)

#ols

Moment_ols<-ols(Yvar[,1]~Xvar[,1], data=data)
Moment_ols     



###################################################################################
### Prep for ANCOVA

## Get tip labels:

n<-length(tree$tip.label)
plot(tree, cex=0.4)
tiplabels()			#Use tip labels to assign group

#Assign Groups:

Theropods<-c(1:6, 18:20)
length(Theropods)
Tyrannosaurs<-c(8,9,11,13,14,16)
length(Tyrannosaurs)
Juveniles<-c(7,10,12,15,17)
length(Juveniles)

n == ((length(Theropods)) + (length(Tyrannosaurs)) + (length(Juveniles)))
#TRUE


#Color-code groups:

tip.col<-rep("black",length(tree$tip.label))
tip.col[Theropods]<-"red"; tip.col[Tyrannosaurs]<-"blue"; tip.col[Juveniles]<-"skyblue1"

#Make Names Vector

dino.names<-c("A. atokensis NCSM 14345", "G. carolinii MUCv-CH-1", "A. jimmadseni MOR 693", "A. fragilis USNM 4734", "Y. shangyouensis CV 00215", "S. hepingensis ZDM 0024", "R. kriegsteini / T. bataar LH PV18", "T. bataar PIN 552 1", "T. bataar ZPAL MgD-I/4", "T. bataar ZPAL MgD-I/3", "T. rex FMNH PR 2081", "T. rex BMRP 2002.4.1", "T. rex AMNH 5027", "D. torosus CMN 8506", "G. libratus AMNH 5664", "G. libratus AMNH 5458", "G. libratus TMP 91.36.500", "E. oxoniensis OUM J13558", "C. nasicornis USNM 4735", "D. wetherelli UCMP 37302")


data$Names<-dino.names

head(data)



##Check classification

plot(tree,label.offset=5, cex=0.4)
tiplabels(pch=19,col=tip.col,cex=3)

dev.off()

#Plot data
Y_lab<-"Agility Moment en Pointe"
X_lab<-"Estimated Body Mass (log10 kg)"

plot(Yvar[,1]~Xvar[,1], ylab=paste0(Y_lab), xlab=paste0(X_lab), pch=20, col=tip.col, cex=2, cex.lab=1, xlim=c(1.5,4.25))
title(main="PGLS of Theropod Agility Moment en Pointe",cex.main=1.5)
abline(model, lwd=2)
#abline(Moment_ols,col="blue", lwd=3,lty=2)		#Remove "#" at beginning of line to plot OLS regression line

legend("topright", legend=c("Theropods","Tyrannosaurs","Putative Juveniles"),text.col=c("red","blue","skyblue1"))

text(model$data$data, data$Names,cex=0.6, pos=3)


#Intervals

#Prep data

tree<-rescale(tree,"lambda",model$param[2])
vcv_tree<-vcv(tree)

#confint
model_ci<-gls.ci(Yvar[,1],Xvar[,1],vcv_tree)
model_ci$model
lines(model_ci$CI.plot$X,model_ci$CI.plot$Lower2.5,lwd=2,lty=4,col="gray47")
lines(model_ci$CI.plot$X,model_ci$CI.plot$Upper2.5,lwd=2,lty=4,col="gray47")

#predint
k<-1
model_pi<-gls.pi(Yvar[,1],Xvar[,1],vcv_tree,k)
model_pi$model
lines(model_pi$PI.plot$X,model_pi$PI.plot$Lower2.5,lwd=2,lty=3,col="gray")
lines(model_pi$PI.plot$X,model_pi$PI.plot$Upper2.5,lwd=2,lty=3,col="gray")




##################
##################
## Design Matrices

Juv<-Juveniles
JuvRest<-setdiff(c(1:length(tree$tip.label)),Juv)

Theropods<-Theropods
TheropodsRest<-setdiff(c(1:length(tree$tip.label)),Theropods)

Tyrannosaurs<-setdiff(c(1:length(tree$tip.label)),c(Juv,Theropods))  #Tyrannosaurs
TyrannosaursRest<-setdiff(c(1:length(tree$tip.label)),Tyrannosaurs)

Sigma<-vcv(rescale(tree,"lambda",model$param[[2]]))
n<-length(tree$tip.label)


#### Build Design Matrices

#Difference in Intercept
    #general model
        designMatrix<-cbind(rep(1,n),scale(Xvar))
        designMatrix

###
    #Juv model
                group1<-rep(length(Juv),n)
                group1[Juv]<-c(-length(JuvRest))
              sum(group1)
        designMatrix_Juv<-cbind(rep(1,n),group1,scale(Xvar))
        designMatrix_Juv
        
        
###
    #Among model with Juv constant
                group1<-rep(length(Juv),n)
                group1[Juv]<-c(-length(JuvRest))
              sum(group1)   #column sums to zero to reduce rounding errors; applies to all folTheropodsing design matrices 
                group2<-rep(1,n)
                group2[Theropods]<-c(length(Tyrannosaurs))
                group2[Tyrannosaurs]<-c(-length(Theropods))
                group2[Juv]<-c(0)
              sum(group2)   #column sums to zero to reduce rounding errors; applies to all folTheropodsing design matrices 
        designMatrix_Among_JuvConstant<-cbind(rep(1,n),group1,group2,scale(Xvar))    #independent variable is standardized to reduce rounding errors; applies to all folTheropodsing design matrices 
        designMatrix_Among_JuvConstant


###
    #Among model with Theropods constant
                group1<-rep(length(Juv),n)
                group1[Juv]<-c(-length(JuvRest))
              sum(group1)   #column sums to zero to reduce rounding errors; applies to all folTheropodsing design matrices 
                group2<-rep(1,n)
                group2[Theropods]<-c(0)
                group2[Tyrannosaurs]<-c(length(Juv))
                group2[Juv]<-c(-length(Tyrannosaurs))
              sum(group2)   #column sums to zero to reduce rounding errors; applies to all folTheropodsing design matrices 
        designMatrix_Among_TheropodsConstant<-cbind(rep(1,n),group1,group2,scale(Xvar))    #independent variable is standardized to reduce rounding errors; applies to all folTheropodsing design matrices 
        designMatrix_Among_TheropodsConstant


###
    #Theropods model
                group1<-rep(length(Theropods),n)
                group1[Theropods]<-c(-length(TheropodsRest))
              sum(group1)
        designMatrix_Theropods<-cbind(rep(1,n),group1,scale(Xvar))
        designMatrix_Theropods


###
    #TyrannosaursvTheropods model
                group2<-rep(1,n)
                group2[Theropods]<-c(length(Tyrannosaurs))
                group2[Tyrannosaurs]<-c(-length(Theropods))
                group2[Juv]<-c(0)
              sum(group2)
        designMatrix_TyrannosaursvTheropods<-cbind(rep(1,n),group2,scale(Xvar))
        designMatrix_TyrannosaursvTheropods


###
    #JuvvTyrannosaurs model
                group2<-rep(1,n)
                group2[Theropods]<-c(0)
                group2[Tyrannosaurs]<-c(length(Juv))
                group2[Juv]<-c(-length(Tyrannosaurs))
              sum(group2)
        designMatrix_JuvvTyrannosaurs<-cbind(rep(1,n),group2,scale(Xvar))
        designMatrix_JuvvTyrannosaurs
        
        
#Difference in Intercept (tests are for whatever columns of X are left out. Those left in are being held constant. Columns not in either are being ignored.)

      #Among groups
          ReducedModel<-designMatrix
          FullModel<-designMatrix_Among_JuvConstant
          as.data.frame(cbind(tree$tip.label,ReducedModel))
          as.data.frame(cbind(tree$tip.label,FullModel))
          Among<-as.matrix(gls.ancova(Yvar[,1],Xvar[,1],Sigma,ReducedModel,FullModel))
      #Juv v Tyrannosaurs | Theropods
          ReducedModel<-designMatrix_Theropods
          FullModel<-designMatrix_Among_TheropodsConstant
          as.data.frame(cbind(tree$tip.label,ReducedModel))
          as.data.frame(cbind(tree$tip.label,FullModel))
          JuvvTyrannosaurs<-as.matrix(gls.ancova(Yvar[,1],Xvar[,1],Sigma,ReducedModel,FullModel))
      #Tyrannosaurs v Theropods | Juv
          ReducedModel<-designMatrix_Juv
          FullModel<-designMatrix_Among_JuvConstant
          as.data.frame(cbind(tree$tip.label,ReducedModel))
          as.data.frame(cbind(tree$tip.label,FullModel))
          TyrannosaursvTheropods<-as.matrix(gls.ancova(Yvar[,1],Xvar[,1],Sigma,ReducedModel,FullModel))
          
          
#getResults
    Results_ancova<-rbind(
      cbind(as.numeric(Among[1,4]),as.numeric(Among[1,5])),
      cbind(as.numeric(JuvvTyrannosaurs[1,4]),as.numeric(JuvvTyrannosaurs[1,5])),
      cbind(as.numeric(TyrannosaursvTheropods[1,4]),as.numeric(TyrannosaursvTheropods[1,5]))
      )
    rownames(Results_ancova)<-c(
      "Among","JuvvTyrannosaurs","TyrannosaursvTheropods")
    colnames(Results_ancova)<-c("F","P")
    Results_ancova
    
#                             F      P
#Among                  11.9537 0.0007
#JuvvTyrannosaurs        0.2814 0.6031
#TyrannosaursvTheropods 21.5640 0.0003

    
    dev.off()
    
rm(list = ls())    